An extensible UDS library for python including the diagnostic service definitions from the ISO14229 standard.

This specific version was developed to fit with kiso testing project (https://github.com/eclipse/kiso-testing)

Currently supports CAN connections using the [Python-CAN] (https://github.com/hardbyte/python-can) package and a standalone ISO-15765 transport protocol.